===============================
qtpyinheritance
===============================

.. image:: https://img.shields.io/travis/klauer/qtpyinheritance.svg
        :target: https://travis-ci.org/klauer/qtpyinheritance

.. image:: https://img.shields.io/pypi/v/qtpyinheritance.svg
        :target: https://pypi.python.org/pypi/qtpyinheritance


Prototype qtpy inheritance-related tools
